C++ API reference
=================

This is the complete reference for the (internal) C++ API of :code:`py4dgeo`.
You only need to consult this documentation if you are aiming to extend the
C++ core of :code:`py4dgeo`.

.. doxygenfile:: py4dgeo/py4dgeo.hpp

.. doxygenfile:: py4dgeo/epoch.hpp

.. doxygenfile:: py4dgeo/searchtree.hpp

.. doxygenfile:: py4dgeo/kdtree.hpp

.. doxygenfile:: py4dgeo/octree.hpp

.. doxygenfunction:: py4dgeo::compute_distances

.. doxygenfunction:: py4dgeo::compute_multiscale_directions

.. doxygenfile:: py4dgeo/segmentation.hpp

.. doxygenfile:: py4dgeo/registration.hpp

.. doxygenfile:: py4dgeo/openmp.hpp
